import { cursorToThreadArray, threadArrayToCursor, initThreadArray } from '@resolve-js/eventstore-base';

const getCursorUntilEventTypes = async ({
  database,
  escapeId,
  escape,
  eventsTableName,
  shapeEvent
}, cursor, untilEventTypes) => {
  if (untilEventTypes.length < 1) {
    throw new Error('Must define at least one event type');
  }

  const tableNameAsId = escapeId(eventsTableName);
  const vectorConditions = cursorToThreadArray(cursor);
  const minThreadCounterConditions = `${vectorConditions.map((threadCounter, threadId) => `${escapeId('threadId')} = ${+threadId} AND ${escapeId('threadCounter')} >= ${+threadCounter} `).join(' OR ')}`;
  const rows = await database.all(`SELECT "threadId", MIN("threadCounter") AS "threadCounter" FROM (
          SELECT "threadId", MIN("threadCounter") AS "threadCounter" FROM ${tableNameAsId} WHERE type IN 
          (${untilEventTypes.map(t => escape(t)).join(', ')}) 
          AND (${minThreadCounterConditions}) 
          GROUP BY "threadId"
          UNION ALL
          SELECT "threadId", MAX("threadCounter")+1 AS "threadCounter" FROM ${tableNameAsId} GROUP BY "threadId")
        GROUP BY "threadId"`);
  const threadCounters = initThreadArray();

  for (const row of rows) {
    threadCounters[row.threadId] = +row.threadCounter;
  }

  return threadArrayToCursor(threadCounters);
};

export default getCursorUntilEventTypes;
//# sourceMappingURL=get-cursor-until-event-types.js.map