"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _constants = require("./constants");

var _getLog = require("./get-log");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

var _resourceErrors = require("./resource-errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initSecrets = async ({
  database,
  databaseFile,
  secretsTableName,
  escapeId
}) => {
  const log = (0, _getLog.getLog)('initSecrets');
  log.debug('initializing secrets table');
  const secretsTableNameAsId = escapeId(secretsTableName);
  const statements = [`CREATE TABLE ${secretsTableNameAsId} (
      ${escapeId('idx')} BIG INT NOT NULL UNIQUE,
      ${escapeId('id')} ${_constants.AGGREGATE_ID_SQL_TYPE} NOT NULL PRIMARY KEY,
      ${escapeId('secret')} text
    )`, `CREATE UNIQUE INDEX IF NOT EXISTS ${escapeId('idx-index')} ON ${secretsTableNameAsId}(
      ${escapeId('idx')}
    )`];
  const errors = await (0, _executeSequence.default)(database, statements, log, error => {
    if ((0, _resourceErrors.isAlreadyExistsError)(error.message)) {
      return new _eventstoreBase.EventstoreResourceAlreadyExistError(`duplicate initialization of the sqlite adapter with the same event database "${databaseFile}" and table "${secretsTableName}" is not allowed`);
    }

    return null;
  });
  log.debug('finished initializing secrets table');
  return errors;
};

var _default = initSecrets;
exports.default = _default;
//# sourceMappingURL=init-secrets.js.map